@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from os import getcwd
 from os.path import normpath, join, getmtime
+
 try:
     import jinja2
 except ImportError, ex:
@@ -20,15 +21,16 @@ def file_loader(fn):
             f = open('%s/templates/%s' % (app_name, fn))
         except (IOError, ValueError):
             assert 0, ERR_MSG
-
     path = normpath(join(getcwd(), f.name))
-    mtime = getmtime(path)
     return f.read().decode('utf-8'), path, lambda: mtime == getmtime(path)
 
 def render_to_string(fn, context):
     global _ENV
     try:
-        return _ENV.get_template(fn).render(context)
+        try:
+            return _ENV.get_template(fn).render(context)
+        except EOFError:
+            raise NameError
     except NameError:
         try:
             _ENV = jinja2.Environment(
